pub(super) struct SessionSlot;Expand description
handle namespace for live RtcSessionState entries
session handles are allowed to live in scheduler queues after the public session key has been removed the store validates the generation before the packet loop polls a session